@@ -922,7 +922,7 @@ class waveAnalysis(object):
 
         return P
 
-    def generate_time_series(self, days=30):
+    def generateTimeSeries(self, days=30):
         """
         Time series of wave characteristics are obtained via both the
         significant wave height and wind speed parameters from the altimeter
@@ -1576,8 +1576,8 @@ class waveAnalysis(object):
         self, series="wh", time=None, lonlat=None, fsave=None, plot=True
     ):
         """
-        This function allows to analyse the seasonal characteristics of each
-        parameter obtained from the altimeter dataset.
+        This function allows  the user to analyse the seasonal characteristics
+        of each parameter obtained from the altimeter dataset.
         For a specified time interval and geographical extent, it computes for a
         given wave variable the monthly seasonality.
         Obtained monthly averaged values are stored and returned with a Pandas
@@ -1610,7 +1610,7 @@ class waveAnalysis(object):
         if self.timeseries is None:
             raise ValueError(
                 "The time series dataframe does not exist, you \
-                              need to run the **generate_time_series()** function \
+                              need to run the **generateTimeSeries()** function \
                               first."
             )
 
